pub fn register_device_peer_with_role(
hub: &mut SurfaceHub,
session: &EdgeId,
profile: &DeviceProfile,
role: SurfaceRole,
) -> SymbolExpand description
Registers a device edge session as a surface with an explicit hub role.
pub fn register_device_peer_with_role(
hub: &mut SurfaceHub,
session: &EdgeId,
profile: &DeviceProfile,
role: SurfaceRole,
) -> SymbolRegisters a device edge session as a surface with an explicit hub role.