Module placement

Module placement 

Browser-local wasm placement descriptors and headless execution harness.

Structs

BrowserPlacementReport
The result of running a browser-local placement.
BrowserPlacementRequest
A request to place a stream fragment on a browser-local engine.
BrowserWasmEngine
A browser-local wasm stream engine and its capabilities.
BrowserWasmEntryPoints
Wasm entrypoint symbols for a browser-local stream engine.

Enums

BrowserBridgeLane
Lane a browser-local placement carries data on.

Functions

browser_audio_worklet_entry_symbol
Stable entrypoint name for the browser AudioWorklet bridge.
browser_server_only_refusal_diagnostic
Diagnostic emitted when a server-only node is offered to browser placement.
browser_wasm_engine_entry_symbol
Stable entrypoint name for the browser wasm stream engine.
browser_wasm_site_symbol
Stable site name for a browser-local wasm placement.