pub struct RemoteTransport { /* private fields */ }Expand description
A network-backed transport that connects a runtime over realize.
Implementations
Sourceimpl RemoteTransport
impl RemoteTransport
Sourcepub fn local_server(endpoint: impl Into<String>) -> Self
pub fn local_server(endpoint: impl Into<String>) -> Self
A local-server transport (HTTP bootstrap + WebSocket live).
Sourcepub fn remote_server(endpoint: impl Into<String>) -> Self
pub fn remote_server(endpoint: impl Into<String>) -> Self
A remote-server transport (HTTP bootstrap + WebSocket live).
Sourcepub fn local_server_address(
endpoint: impl Into<String>,
address: ServerAddress,
) -> Self
pub fn local_server_address( endpoint: impl Into<String>, address: ServerAddress, ) -> Self
A local-server transport targeting an explicit server address.
Sourcepub fn remote_server_address(
endpoint: impl Into<String>,
address: ServerAddress,
) -> Self
pub fn remote_server_address( endpoint: impl Into<String>, address: ServerAddress, ) -> Self
A remote-server transport targeting an explicit server address.
Sourcepub fn address(&self) -> &ServerAddress
pub fn address(&self) -> &ServerAddress
The server address this transport connects to.
Sourcepub fn with_offered_codecs(self, offered_codecs: Vec<Symbol>) -> Self
pub fn with_offered_codecs(self, offered_codecs: Vec<Symbol>) -> Self
Override the codec offer set used during negotiation.
Sourcepub fn with_max_in_flight(self, max_in_flight: usize) -> Self
pub fn with_max_in_flight(self, max_in_flight: usize) -> Self
Override the maximum number of correlated requests allowed in flight.
Sourcepub fn with_timeout(self, timeout: Duration) -> Self
pub fn with_timeout(self, timeout: Duration) -> Self
Override the request timeout used for server answers.
Sourcepub fn connect(&mut self, cx: &mut Cx) -> Result<()>
pub fn connect(&mut self, cx: &mut Cx) -> Result<()>
Request a remote connection and negotiate the server codec.
Sourcepub fn disconnect(&mut self)
pub fn disconnect(&mut self)
Mark the remote channel disconnected.
Sourcepub fn begin_reconnect(&mut self)
pub fn begin_reconnect(&mut self)
Mark the remote channel reconnecting.
Sourcepub fn stream_control_frame(
&self,
cx: &mut Cx,
codec: Symbol,
control: &StreamControl,
) -> Result<ServerFrame>
pub fn stream_control_frame( &self, cx: &mut Cx, codec: Symbol, control: &StreamControl, ) -> Result<ServerFrame>
Encode a stream-fabric control frame for server-backed transports.