pub enum WebStreamOperation {
Read,
Subscribe,
Push,
Cancel,
Stats,
}Expand description
Web bridge stream operations and their corresponding fabric controls.
Variants
Read
Read up to limit packets.
Subscribe
Subscribe to stream metadata and status.
Push
Push one envelope into a stream.
Cancel
Cancel the stream.
Stats
Inspect stream statistics.
Implementations
Sourceimpl WebStreamOperation
impl WebStreamOperation
Sourcepub fn wire_label(self) -> &'static str
pub fn wire_label(self) -> &'static str
Returns the stable wire label for this operation.
Sourcepub fn fabric_symbol(self) -> Symbol
pub fn fabric_symbol(self) -> Symbol
Returns the fabric control symbol this operation maps to.
Sourcepub fn capability(self) -> CapabilityName
pub fn capability(self) -> CapabilityName
Returns the capability required to invoke this operation.