pub struct FabricTransport { /* private fields */ }Expand description
A transport that commits operations by delegating to an
EvalFabric.
Reads return locally stored values and change events accumulate locally;
Transport::realize is forwarded to the fabric, whose reply value becomes
the new value of the realized resource.
Implementations
Sourceimpl FabricTransport
impl FabricTransport
Sourcepub fn new(fabric: EvalFabricRef) -> Self
pub fn new(fabric: EvalFabricRef) -> Self
A connected, empty transport over fabric (with its own kernel context).